/**
 * @file ejemplo_doxygen.h
 * @brief Este es un ejemplo de uso de doxygen como herramienta de documentación para el curso de Sistemas Embebidos
 *
 * Proyecto Ejemplo
 * Modulo Ejemplo
 * Este modulo agrupa las funciones de tal tipo que hacen
 * tal o cual categoria de cosas
 *
 * Los comentarios que aparecen en este archivo se refieren
 * a la funcionalidad y la interface del modulo.
 * Nunca a su implementacion.
 *
 * ejemplo.h
 * El programa tal, que hace esto y lo otro...
 *
 * @author  Tito Livio <tliv@example.com>
 * @version 1.1
 * Se corrige Bug#0001 en la implementacion de sumar
 * @date 27 Marzo 2014
 * @author  yo@fing.edu.uy
 * @version 1.2
 * Se corrige Bug#0002 y Bug#0003 en la implementacion de Doxygen
 * @date 30 Marzo 2017
 */


#ifndef EJEMPLO_H_INCLUDED
#define EJEMPLO_H_INCLUDED


/**********************************************************
* Constantes compartidas entre varios modulos
**********************************************************/

#define C1			1			// La primer constante
#define LBUF		80			// Largo buffer de algo


/**********************************************************
* Nuevos tipos definidos que son parte de la interface
* del modulo
**********************************************************/

//---------------------------------------------------------
/** Defino tipo para alguna cosa */
typedef  MiTipo int;

//---------------------------------------------------------
/** Defino tipo para funciones a llamar con interface std
    (esto es parte de otro ejemplo y no importa el detalle)
 */
typedef  int (*ShellFunPtr)(unsigned int argc, char** argv);

/** TRUE si las interrupciones está habilitadas */
bool intEnabled;

/**********************************************************
* Funciones del modulo
* Cada funcion debe tener comentarios indicando que hace
* y cual es su interface
**********************************************************/
 /**
  * <Una descripción corta> Ejemplo: Suma dos enteros
  * @param int a: Descripción de un parámetro de entrada de la función
  * @param int b: El otro sumando
  * @return int Descripción del valor de retorno de la función (si lo hay)
  */

int sumar(int a, int b);



#endif // EJEMPLO_H_INCLUDED
